@@ -22,6 +22,7 @@ from rdflib.serializer import Serializer
 from uuid import uuid4
 from rdflib.namespace import DC, DCTERMS, DOAP, FOAF, SKOS, OWL, RDF, RDFS, VOID, XMLNS, XSD
 from json import dumps
+from bson.objectid import ObjectId 
 
 
 SHC = Namespace("http://data.shinc.co.uk/")
@@ -35,7 +36,7 @@ class SOFImageExtractor:
 
 
     def ocr(self, image):
-        fn = self.tmppath + "/" + str(uuid4())
+        fn = self.tmppath + "/" + str(ObjectId())
         cp = subprocess.run(["tesseract", "{}".format(image), "{}".format(fn)], check=True)
         if cp.returncode != 0:
             del environ[response_key]
@@ -177,7 +178,7 @@ class SOFTextExtractor:
         pass
 
     def extract(self, text, starttext=None, endtext=None, startdate=None, enddate=None, dateorder=None, timemask="hh:mm", tz=timezone.utc):
-        sofs = SOF(id = str(uuid4()))
+        sofs = SOF(id = str(ObjectId()))
         full_sofs = []
         summary_sofs = []
         date_count = startdate
@@ -190,8 +191,8 @@ class SOFTextExtractor:
             text = line.lower()
             if started and self.textContainsSof(text):
                 sof= self.extractLine(text, date_count, dateorder, timemask, tz)
-                if sof.startdatetime:
-                    date_count = sof.startdatetime
+                if sof.dateTimeFrom:
+                    date_count = sof.dateTimeFrom
                 full_sofs.append(sof) if sof not in full_sofs else sofs
                 if next((x for x in self.soflist.softypes if x.id == sof.id and x.summary), None):
                     summary_sofs.append(sof) if sof not in summary_sofs else summary_sofs
@@ -212,7 +213,7 @@ class SOFTextExtractor:
         text = text.lower()
         restext = text
         softype = self.textContainsSof(text)
-        id = str(uuid4())
+        id = str(ObjectId())
         sof = SOFEvent(id, softype.id, softype.description)
         if softype.summary:
             sof.summary = True
@@ -251,17 +252,17 @@ class SOFTextExtractor:
         if not time_from:
             time_from = date_from
         if date_from and time_from:
-            sof.startdatetime = self.generateDatetime(date_from, time_from,tz)
+            sof.dateTimeFrom = self.generateDatetime(date_from, time_from,tz)
         if softype.bounded and time_to:
             if not date_to:
                 date_to = date_from
-            sof.enddatetime = self.generateDatetime(date_to, time_to,tz)
+            sof.dateTimeTo = self.generateDatetime(date_to, time_to,tz)
         return sof
 
     def textContainsSof(self, text):
         res = False
         for sof in self.soflist.softypes:
-            if sof.description.lower() in text:
+            if sof.name.lower() in text:
                 return sof
         return res
 
@@ -441,15 +442,15 @@ class SOFPDFExtractor:
 class SOFEvent:
     def __init__(self, id, type=None, description=None, time_from=None, time_to=None, date_from=None, date_to=None, summary=False):
         self.id = id
-        self.type = type
-        self.startdatetime = date_from
+        self.eventType = type
+        self.dateTimeFrom = date_from
         self.description = description
-        self.enddatetime = time_to
+        self.dateTimeTo = time_to
         self.summary = summary
 
     def __eq__(self, other):
         if (isinstance(other, SOFEvent)):
-            return self.type == other.type and self.startdatetime == other.startdatetime and self.description == other.description
+            return self.eventType == other.eventType and self.dateTimeFrom == other.dateTimeFrom and self.description == other.description
         return False
 
 class SOF:
@@ -464,14 +465,15 @@ class SOF:
             self.sofs.append(sof)
 
     def reorder(self):
-        orderedsofs = sorted(self.sofs, key=lambda x: x.startdatetime)
+        orderedsofs = sorted(self.sofs, key=lambda x: x.dateTimeFrom)
         self.sofs = orderedsofs
 
 
 
 class SOFType:
-    def __init__(self,id, description, bounded=False, notation=False, stoppage=False, display=False, summary=False):
+    def __init__(self,id, name, description, bounded=False, notation=False, stoppage=False, display=False, summary=False):
         self.id = id
+        self.name = name
         self.description = description
         self.bounded = bounded
         self.notation = notation
@@ -496,8 +498,7 @@ class SOFList:
             for row in csv_reader:
                 name = row[0]
                 uri = URIRef(SHC + name.replace(" ","-"))
-                softype = SOFType(SHC + name.replace(" ","-"), name)
-                softype.description = name
+                softype = SOFType(name.replace(" ","-"), name, name)
                 self.sofs.add((uri, RDFS.label, Literal(name, lang="en")))
                 self.sofs.add((uri, RDFS.subClassOf, SHC.Event))
                 if row[1] == "1":
@@ -517,6 +518,9 @@ class SOFList:
         rows = self.sofs.query("SELECT ?type WHERE {?type rdfs:label '" + text + "' } ", initNs=NS)
         return str(rows[0])
 
+    def getSofTypeFromDescription(self, text):
+        return next((sof for sof in self.softypes if self.description == text), None)
+
 
 class SOFException(Exception):
     pass
